basxbread.contrib package
=========================

.. automodule:: basxbread.contrib
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   basxbread.contrib.document_templates
   basxbread.contrib.languages
   basxbread.contrib.publicurls
   basxbread.contrib.reports
   basxbread.contrib.workflows
